@@ -7,7 +7,7 @@ def dask():
 
     install_min(package="dask", pip_name="dask[complete]", version="2021.4.0")
 
-    print(F"{'dask'.rjust(50)} : {INFO}")
+    # print(F"{'dask'.rjust(50)} : {INFO}")
 
     from dask.distributed import Client, LocalCluster
     cluster = LocalCluster()
